pub struct JointLimits {
pub max: f32,
pub min: f32,
pub bounceMinVelocity: Option<f32>,
pub bounciness: Option<f32>,
pub contactDistance: Option<f32>,
pub maxBounce: Option<f32>,
pub minBounce: Option<f32>,
}Expand description
JointLimits is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: JointLimits is used by the HingeJoint to limit the joints angle. See Also: HingeJoint.
Fields
max: f32The upper angular limit (in degrees) of the joint.
min: f32The lower angular limit (in degrees) of the joint.
bounceMinVelocity: Option<f32>The minimum impact velocity which will cause the joint to bounce. f32: (5.1.0f1 - 2022.3.2f1)
bounciness: Option<f32>Determines the size of the bounce when the joint hits it’s limit. Also known as restitution. f32: (5.1.0f1 - 2022.3.2f1)
contactDistance: Option<f32>Distance inside the limit value at which the limit will be considered to be active by the solver. f32: (5.0.0f4 - 2022.3.2f1)
maxBounce: Option<f32>f32: (3.4.0 - 5.0.4f1)
minBounce: Option<f32>f32: (3.4.0 - 5.0.4f1)