pub struct MinMaxCurve {
pub maxCurve: AnimationCurve,
pub minCurve: AnimationCurve,
pub minMaxState: i32,
pub scalar: f32,
pub minScalar: Option<f32>,
}Expand description
MinMaxCurve is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for a Min-Max Curve. Min-Max Curve. describes functions which take a value between a minimum and maximum limit and return a value based on ParticleSystem.MinMaxCurve.mode. Depending on the mode, this may return randomized values.
For modes that require curves, the value returned is dependent on one or two curves designed in the ParticleSystem Inspector, that can be evaluated to a single value between -n and n, where n is a constant also set in the Inspector. See ParticleSystemCurveMode for more information.See Also: ParticleSystem.
Fields
maxCurve: AnimationCurveminCurve: AnimationCurveminMaxState: i32scalar: f32minScalar: Option<f32>f32: (5.6.1f1 - 2022.3.2f1)