pub struct SerializedProperty {
pub m_Attributes: Vec<String>,
pub m_DefTexture: SerializedTextureProperty,
pub m_Description: String,
pub m_Flags: u32,
pub m_Name: String,
pub m_Type: i32,
pub m_DefValue_0_: Option<f32>,
pub m_DefValue_1_: Option<f32>,
pub m_DefValue_2_: Option<f32>,
pub m_DefValue_3_: Option<f32>,
}Expand description
SerializedProperty is a sub class of the Unity engine since version 5.5.0f3. Exert from Unity’s scripting documentation: SerializedProperty and SerializedObject are classes for editing properties on objects in a completely generic way that automatically handles undo, multi-object editing and Prefab overrides. SerializedProperty is primarily used to read or change the value of a property. It can also iterate through the properties of an object using Next. See Also: SerializedObject class, Editor class.
Fields
m_Attributes: Vec<String>m_DefTexture: SerializedTexturePropertym_Description: Stringm_Flags: u32m_Name: StringName of the property. (Read Only)
m_Type: i32Type name of the property. (Read Only)
m_DefValue_0_: Option<f32>f32: (5.5.0f3 - 2022.3.2f1)
m_DefValue_1_: Option<f32>f32: (5.5.0f3 - 2022.3.2f1)
m_DefValue_2_: Option<f32>f32: (5.5.0f3 - 2022.3.2f1)
m_DefValue_3_: Option<f32>f32: (5.5.0f3 - 2022.3.2f1)