ReadUrexExt

Trait ReadUrexExt 

pub trait ReadUrexExt: ReadBytesExt {
Show 13 methods // Provided methods fn read_array_len<T: ByteOrder>(&mut self) -> Result<usize, Error> { ... } fn read_cstr(&mut self) -> Result<String, Error> { ... } fn read_string<T: ByteOrder>(&mut self) -> Result<String, Error> { ... } fn read_string_sized(&mut self, len: usize) -> Result<String, Error> { ... } fn read_bytes<T: ByteOrder>(&mut self) -> Result<Vec<u8>, Error> { ... } fn read_bytes_sized(&mut self, len: usize) -> Result<Vec<u8>, Error> { ... } fn read_bool(&mut self) -> Result<bool, Error> { ... } fn read_i16_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i16>, Error> { ... } fn read_i32_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i32>, Error> { ... } fn read_i64_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i64>, Error> { ... } fn read_u16_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u16>, Error> { ... } fn read_u32_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u32>, Error> { ... } fn read_u64_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u64>, Error> { ... }
}

Provided Methods

fn read_array_len<T: ByteOrder>(&mut self) -> Result<usize, Error>

fn read_cstr(&mut self) -> Result<String, Error>

fn read_string<T: ByteOrder>(&mut self) -> Result<String, Error>

fn read_string_sized(&mut self, len: usize) -> Result<String, Error>

fn read_bytes<T: ByteOrder>(&mut self) -> Result<Vec<u8>, Error>

fn read_bytes_sized(&mut self, len: usize) -> Result<Vec<u8>, Error>

fn read_bool(&mut self) -> Result<bool, Error>

fn read_i16_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i16>, Error>

Reads an array of i16s. If len is none the reader will determine the length by reading it.

fn read_i32_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i32>, Error>

Reads an array of i32s. If len is none the reader will determine the length by reading it.

fn read_i64_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<i64>, Error>

Reads an array of i64s. If len is none the reader will determine the length by reading it.

fn read_u16_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u16>, Error>

Reads an array of u16s. If len is none the reader will determine the length by reading it.

fn read_u32_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u32>, Error>

Reads an array of u32s. If len is none the reader will determine the length by reading it.

fn read_u64_array<T: ByteOrder>( &mut self, len: Option<usize>, ) -> Result<Vec<u64>, Error>

Reads an array of u64s. If len is none the reader will determine the length by reading it.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<R: Read + ?Sized> ReadUrexExt for R